@@ -1,4 +1,4 @@
-// MeshOptimizer - Copyright (C) 2013-2024 UCLouvain-ULiege
+// MeshOptimizer - Copyright (C) 2013-2025 UCLouvain-ULiege
 //
 // Permission is hereby granted, free of charge, to any person
 // obtaining a copy of this software and associated documentation
@@ -28,8 +28,7 @@
 const double ObjContrib::BIGVAL = 1.e300;
 
 ObjContrib::ObjContrib(std::string mesName, std::string name)
-  : _parent(this), _min(BIGVAL), _max(-BIGVAL), _measureName(mesName),
-    _name(name)
+  : _parent(this), _measureName(mesName), _name(name), _min(BIGVAL), _max(-BIGVAL)
 {
 }
 
