@@ -1,4 +1,4 @@
-// MeshOptimizer - Copyright (C) 2013-2023 UCLouvain-ULiege
+// MeshOptimizer - Copyright (C) 2013-2025 UCLouvain-ULiege
 //
 // Permission is hereby granted, free of charge, to any person
 // obtaining a copy of this software and associated documentation
@@ -62,7 +62,7 @@ Patch::Patch(const std::map<MElement *, GEntity *> &element2entity,
         fixBndEntities.insert(gf->getMeshMaster());
       }
     }
-    Msg::Info("Considering %lu entities with periodic constraints",
+    Msg::Info("Considering %zu entities with periodic constraints",
               fixBndEntities.size());
   }
 
