@@ -64,14 +64,14 @@ HXTStatus hxtEmptyMesh(HXTMesh* mesh, HXTDelaunayOptions* delOptions)
   HXT_CHECK( hxtDelaunaySteadyVertices(mesh, delOptions, nodeInfo, numToInsert) );
   delOptions->perfectDelaunay = 0;
 
-#ifdef DEBUG
+  //#ifdef DEBUG
   #pragma omp parallel for simd aligned(nodeInfo:SIMD_ALIGN)
   for (uint32_t i=0; i<numToInsert; i++) {
     if(nodeInfo[i].status!=HXT_STATUS_TRUE){
       HXT_WARNING("point %u of the empty mesh was not inserted\n", nodeInfo[i].node);
     }
   }
-#endif
+  //#endif
 
   HXT_CHECK( hxtAlignedFree(&nodeInfo) );
 
@@ -127,9 +127,10 @@ static int getBestCenter(double p[4][4], double nodalSize[4], double center[4],
 
   // these formula accumulate a lot of errors...
   double xa = sqrt(e0l2);
-  double xb = (e1l2 + e0l2 - e3l2)/(2*xa);
+  double invtwoxa = 1./(2*xa);
+  double xb = (e1l2 + e0l2 - e3l2)*invtwoxa;
   double yb = sqrt(e1l2 - xb*xb);
-  double xc = (e2l2 + e0l2 - e4l2)/(2*xa);
+  double xc = (e2l2 + e0l2 - e4l2)*invtwoxa;
   double yc = (e1l2 + e2l2 - e5l2 - 2*xb*xc)/(2*yb);
   double zc = sqrt(e2l2 - xc*xc - yc*yc);
 
@@ -215,7 +216,7 @@ static int getBestCenter(double p[4][4], double nodalSize[4], double center[4],
     if(!isfinite(bary0) || !isfinite(bary1) || !isfinite(bary2) || !isfinite(bary3))
       bary0 = bary1 = bary2 = bary3 = 0.25;
 
-    // compute the cartesian coordinates from the barycentric ones
+    // compute the Cartesian coordinates from the barycentric ones
     double otherCenter[4];
     otherCenter[0] = bary0*p[0][0] + bary1*p[1][0] + bary2*p[2][0] + bary3*p[3][0];
     otherCenter[1] = bary0*p[0][1] + bary1*p[1][1] + bary2*p[2][1] + bary3*p[3][1];
@@ -297,9 +298,9 @@ static uint64_t* scanbsearch(uint64_t* array, uint64_t key, size_t num)
  *  - startTet[maxThreads] = mesh->tetrahedra.num
  *  - `startPt[t+1] - startPt[t]` gives how many point will be created by thread t
  */
-static HXTStatus balanceRefineWork(HXTMesh* mesh, uint32_t* startPt, size_t* startTet, int maxThreads)
+static HXTStatus balanceRefineWork(HXTMesh* mesh, uint32_t* startPt, uint64_t* startTet, int maxThreads)
 {
-  size_t* scan;
+  uint64_t* scan;
   uint32_t ptPerThreadGoal;
   HXT_CHECK( hxtAlignedMalloc(&scan, sizeof(size_t) * mesh->tetrahedra.num) );
 
@@ -343,7 +344,7 @@ static HXTStatus balanceRefineWork(HXTMesh* mesh, uint32_t* startPt, size_t* sta
 
     // we want to find i such that scan[i] = scanToFind.
     // we do a simple binary search in the prefix scan array to find `i`
-    size_t* pfnd = scanbsearch(scan, scanToFind, mesh->tetrahedra.num);
+    uint64_t* pfnd = scanbsearch(scan, scanToFind, mesh->tetrahedra.num);
     startTet[threadID] = pfnd  - scan;
     if(startTet[threadID] < mesh->tetrahedra.num)
       startPt[threadID] = *pfnd;
