@@ -1,4 +1,4 @@
-// Gmsh - Copyright (C) 1997-2024 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2025 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file in the Gmsh root directory for license information.
 // Please report all issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
@@ -59,7 +59,8 @@ void CTX::init()
   cg[0] = cg[1] = cg[2] = 0.;
   polygonOffset = 0;
   printing = 0;
-  meshTimer[0] = meshTimer[1] = meshTimer[2] = 0.;
+  mesh.timer[0] = mesh.timer[1] = mesh.timer[2] = 0.;
+  mesh.minQuality = mesh.avgQuality = 0.;
   drawRotationCenter = 0;
   pickElements = 0;
   geom.draw = 1;
