@@ -1,4 +1,4 @@
-// Gmsh - Copyright (C) 1997-2023 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2025 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file in the Gmsh root directory for license information.
 // Please report all issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
@@ -16,7 +16,7 @@ class GamePad;
 
 struct contextMeshOptions {
   // mesh algorithms
-  int optimize, optimizeNetgen, refineSteps;
+  int optimize, optimizeNetgen, refineSteps, optimizePyramids;
   int smoothCrossField, crossFieldClosestPoint;
   double lcFactor, randFactor, randFactor3d, lcIntegrationPrecision;
   double optimizeThreshold, normals, tangents, explode, angleSmoothNormals;
@@ -31,7 +31,7 @@ struct contextMeshOptions {
   int recombineNodeRepositioning;
   double recombineMinimumQuality;
   int recombine3DAll, recombine3DLevel, recombine3DConformity;
-  int flexibleTransfinite, transfiniteTri, maxRetries;
+  int flexibleTransfinite, quasiTransfinite, transfiniteTri, maxRetries;
   int order, secondOrderLinear, secondOrderIncomplete;
   int meshOnlyVisible, meshOnlyEmpty;
   int minCircleNodes, minCurveNodes, minLineNodes;
@@ -46,7 +46,7 @@ struct contextMeshOptions {
   int boundaryLayerFanElements;
   int maxNumThreads1D, maxNumThreads2D, maxNumThreads3D;
   double angleToleranceFacetOverlap, toleranceReferenceElement;
-  int renumber, compoundClassify, reparamMaxTriangles;
+  int renumber, compoundClassify, reparamMaxTriangles, reproducible;
   double compoundLcFactor;
   unsigned int randomSeed;
   int nLayersPerGap;
@@ -61,7 +61,7 @@ struct contextMeshOptions {
   int saveAll, saveTri, saveGroupsOfNodes, saveGroupsOfElements;
   int readGroupsOfElements;
   int binary, bdfFieldFormat;
-  int unvStrictFormat, stlRemoveDuplicateTriangles, stlOneSolidPerSurface;
+  int unvStrictFormat, stlRemoveBadTriangles, stlOneSolidPerSurface;
   double stlLinearDeflection, stlAngularDeflection;
   bool stlLinearDeflectionRelative;
   int saveParametric, saveTopology, saveWithoutOrphans, zoneDefinition;
@@ -88,6 +88,10 @@ struct contextMeshOptions {
   double nodeSize, lineWidth;
   int dual, voronoi, drawSkinOnly, colorCarousel, labelSampling;
   int smoothNormals, clip;
+  // records cpu times for 1D, 2D and 3D mesh generation
+  double timer[3];
+  // records minimal and average mesh quality after 2D and 3D mesh generation
+  double minQuality, avgQuality;
 };
 
 struct contextGeometryOptions {
@@ -100,9 +104,12 @@ struct contextGeometryOptions {
   double tolerance, toleranceBoolean, snap[3], transform[3][3], offset[3];
   int occAutoFix, occAutoEmbed, occFastUnbind;
   int occFixDegenerated, occFixSmallEdges, occFixSmallFaces;
-  int occSewFaces, occMakeSolids, occParallel, occBooleanPreserveNumbering;
+  int occSewFaces, occMakeSolids, occParallel;
   int occBoundsUseSTL, occDisableSTL, occImportLabels, occExportOnlyVisible;
-  int occUnionUnify, occThruSectionsDegree, occUseGenericClosestPoint;
+  int occBooleanCheckInverted, occBooleanGlue, occBooleanNonDestructive;
+  int occBooleanPreserveNumbering, occBooleanSimplify;
+  int occThruSectionsDegree, occUseGenericClosestPoint;
+  int occBrepFormatVersion;
   double occScaling;
   std::string occTargetUnit;
   // STEP file outputs
@@ -163,6 +170,8 @@ public:
   std::string homeDir;
   // file history
   std::vector<std::string> recentFiles;
+  // default number format in graphics window
+  std::string numberFormat;
   // create mesh statistics report (0: do nothing, 1: create, 2: append)
   int createAppendMeshStatReport;
   // behavior on error
@@ -302,8 +311,6 @@ public:
   // vector display type and options (for normals, etc.)
   int vectorType;
   double arrowRelHeadRadius, arrowRelStemRadius, arrowRelStemLength;
-  // records cpu times for 1-D, 2-D and 3-D mesh generation
-  double meshTimer[3];
   // dynamic variable tracking if the bbox is currently imposed
   int forcedBBox;
   // enable selection/hover/picking using the mouse
