@@ -1,4 +1,4 @@
-// Gmsh - Copyright (C) 1997-2024 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2025 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file in the Gmsh root directory for license information.
 // Please report all issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
@@ -6,7 +6,7 @@
 #include <stdlib.h>
 #include "GmshGlobal.h"
 
-#if defined(WIN32) && !defined(__CYGWIN__)
+#if (defined(WIN32) || defined(_WIN32)) && (defined(__MINGW32__) || (defined(_MSC_VER) && !defined(HAVE_FLTK)))
 
 // in order to handle non-ASCII command line arguments on Windows, use wmain()
 // instead of main() (we could also use main() and retrieve the "wide" args with
