@@ -1,4 +1,4 @@
-// Gmsh - Copyright (C) 1997-2023 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2025 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file in the Gmsh root directory for license information.
 // Please report all issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
@@ -15,4 +15,8 @@ std::string patternChooser();
 
 int cgnsImport();
 
+int simpleTextDisplay(const char *title, const std::string &text);
+int simpleTextEditor(const char *title, const std::string &help,
+                     std::string &text);
+
 #endif
