@@ -1,4 +1,4 @@
-// Gmsh - Copyright (C) 1997-2023 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2025 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file in the Gmsh root directory for license information.
 // Please report all issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
@@ -106,6 +106,11 @@ void onelab_cb(Fl_Widget *w, void *data)
   o.setAttribute("Persistent", "1");
   onelab::server::instance()->set(o);
 
+  if(action == "reload") {
+    // for outside code that will want to rebuild the geometry
+    return;
+  }
+
   if(action == "refresh") {
     onelabUtils::updateGraphs();
     FlGui::instance()->rebuildTree(true);
@@ -458,7 +463,7 @@ static void onelab_subtree_cb(Fl_Widget *w, void *data)
 
 void onelabGroup::_computeWidths()
 {
-  // "-FL_NORMAL_SIZE" to have space for a scrollbar to the right
+  // "- 1.1 * FL_NORMAL_SIZE" to have space for a scrollbar to the right
   _baseWidth = _tree->w() - _tree->marginleft() - 1.1 * FL_NORMAL_SIZE;
   // not sure why we have the "-2" correction at the end, but this is what is
   // needed to make things pixel-correct.
@@ -500,9 +505,12 @@ onelabGroup::onelabGroup(int x, int y, int w, int h, const char *l)
   // _tree->resizable(0);
   _tree->end();
 
-  _computeWidths();
   _widgetLabelRatio = 0.5;
 
+  // dummy values for now; will be updated with _computeWidths()
+  _baseWidth = _tree->w() - _tree->marginleft();
+  _indent = _tree->connectorwidth();
+
   int BB2 = BB / 2 + 4;
 
   _butt[0] =
@@ -1040,10 +1048,15 @@ Fl_Widget *addParameterWidget(onelab::number &p, int xx, int yy, int ww, int hh,
 
   // non-editable value
   if(p.getReadOnly()) {
-    outputRange *but = new outputRange(xx, yy, ww, hh);
+    outputRange *but = new outputRange(xx, yy, ww, hh,
+                                       onelab::parameter::maxNumber());
     but->callback(onelab_number_output_range_cb, (void *)path);
     but->numberFormat(p.getAttribute("NumberFormat"));
     but->value(p.getValue());
+    but->minimum(p.getMin());
+    but->maximum(p.getMax());
+    but->step(p.getStep());
+    but->choices(p.getChoices());
     but->align(FL_ALIGN_RIGHT | FL_ALIGN_CLIP);
     but->graph(p.getAttribute("Graph"));
     if(highlight) but->color(c);
@@ -1420,7 +1433,6 @@ void onelabGroup::rebuildTree(bool deleteWidgets)
   setButtonVisibility();
 
   FL_NORMAL_SIZE -= CTX::instance()->deltaFontSize;
-  _computeWidths();
 
   std::set<std::string> closed = _getClosedGmshMenus();
 
@@ -1436,6 +1448,7 @@ void onelabGroup::rebuildTree(bool deleteWidgets)
   }
   _tree->sortorder(FL_TREE_SORT_ASCENDING);
   _tree->selectmode(FL_TREE_SELECT_NONE);
+  _computeWidths();
 
   // hide all the widgets we have added in the tree to make sure they don't get
   // spurious events (until they are deleted)
