@@ -1,4 +1,4 @@
-// Gmsh - Copyright (C) 1997-2023 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2025 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file in the Gmsh root directory for license information.
 // Please report all issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
@@ -244,7 +244,7 @@ int GModel::writeCGNS(const std::string &name, bool saveAll,
   // interface entities
   Vertex2LocalData interfVert2Local;
   initInterfVertex2LocalData(entitiesPer, entitiesInterf, interfVert2Local);
-  Msg::Info("%lu periodic/interface nodes", interfVert2Local.size());
+  Msg::Info("%zu periodic/interface nodes", interfVert2Local.size());
 
   // write partitions and periodic/partition connectivities
   std::set<int> eleMshTypes;
