@@ -1,9 +1,10 @@
-// Gmsh - Copyright (C) 1997-2023 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2025 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file in the Gmsh root directory for license information.
 // Please report all issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
 
 #include <stdio.h>
+#include <ctype.h>
 #include <string>
 #include <algorithm>
 #include <sstream>
@@ -19,6 +20,18 @@
 
 static bool invalidChar(char c) { return !(c >= 32 && c <= 126); }
 
+static char *fgets0(char *buffer, int size, FILE *fp)
+{
+  // same as fgets but ignores empty lines
+  while(1) {
+    char *ret = fgets(buffer, size, fp);
+    if(!ret) return nullptr;
+    for(std::size_t i = 0; i < strlen(ret); i++) {
+      if(!isspace(ret[i])) return ret;
+    }
+  }
+}
+
 int GModel::readSTL(const std::string &name, double tolerance)
 {
   FILE *fp = Fopen(name.c_str(), "rb");
@@ -34,7 +47,7 @@ int GModel::readSTL(const std::string &name, double tolerance)
 
   // "solid", or binary data header
   char buffer[256];
-  if(!fgets(buffer, sizeof(buffer), fp)) {
+  if(!fgets0(buffer, sizeof(buffer), fp)) {
     fclose(fp);
     return 0;
   }
@@ -52,10 +65,10 @@ int GModel::readSTL(const std::string &name, double tolerance)
     points.resize(1);
     while(!feof(fp)) {
       // "facet normal x y z" or "endsolid"
-      if(!fgets(buffer, sizeof(buffer), fp)) break;
+      if(!fgets0(buffer, sizeof(buffer), fp)) break;
       if(!strncmp(buffer, "endsolid", 8) || !strncmp(buffer, "ENDSOLID", 8)) {
         // "solid"
-        if(!fgets(buffer, sizeof(buffer), fp)) break;
+        if(!fgets0(buffer, sizeof(buffer), fp)) break;
         if(!strncmp(buffer, "solid", 5) || !strncmp(buffer, "SOLID", 5)) {
           if(strlen(buffer) > 6)
             names.push_back(&buffer[6]);
@@ -63,14 +76,14 @@ int GModel::readSTL(const std::string &name, double tolerance)
             names.push_back("");
           points.resize(points.size() + 1);
           // "facet normal x y z"
-          if(!fgets(buffer, sizeof(buffer), fp)) break;
+          if(!fgets0(buffer, sizeof(buffer), fp)) break;
         }
       }
       // "outer loop"
-      if(!fgets(buffer, sizeof(buffer), fp)) break;
+      if(!fgets0(buffer, sizeof(buffer), fp)) break;
       // "vertex x y z"
       for(int i = 0; i < 3; i++) {
-        if(!fgets(buffer, sizeof(buffer), fp)) break;
+        if(!fgets0(buffer, sizeof(buffer), fp)) break;
         char s1[256];
         double x, y, z;
         if(sscanf(buffer, "%s %lf %lf %lf", s1, &x, &y, &z) != 4) break;
@@ -80,9 +93,9 @@ int GModel::readSTL(const std::string &name, double tolerance)
         bbox += p;
       }
       // "endloop"
-      if(!fgets(buffer, sizeof(buffer), fp)) break;
+      if(!fgets0(buffer, sizeof(buffer), fp)) break;
       // "endfacet"
-      if(!fgets(buffer, sizeof(buffer), fp)) break;
+      if(!fgets0(buffer, sizeof(buffer), fp)) break;
     }
   }
 
@@ -193,21 +206,30 @@ int GModel::readSTL(const std::string &name, double tolerance)
         v[k] = pos.find(x, y, z);
         if(!v[k])
           Msg::Error("Could not find node at position (%.16g, %.16g, %.16g) "
-                     "with tol=%.16g",
-                     x, y, z, eps);
+                     "with tol=%.16g", x, y, z, eps);
       }
       if(!v[0] || !v[1] || !v[2]) {
         // error
       }
       else if(v[0] == v[1] || v[0] == v[2] || v[1] == v[2]) {
-        Msg::Debug("Skipping degenerated triangle %lu %lu %lu", v[0]->getNum(),
+        Msg::Debug("Skipping degenerated triangle %zu %zu %zu", v[0]->getNum(),
                    v[1]->getNum(), v[2]->getNum());
         nbDegen++;
       }
-      else if(CTX::instance()->mesh.stlRemoveDuplicateTriangles) {
+      else if(CTX::instance()->mesh.stlRemoveBadTriangles) {
         MFace mf(v[0], v[1], v[2]);
         if(unique.find(mf) == unique.end()) {
-          faces[i]->triangles.push_back(new MTriangle(v[0], v[1], v[2]));
+          if(CTX::instance()->mesh.stlRemoveBadTriangles > 1) {
+            double a = mf.approximateArea();
+            if(a < tolerance * tolerance) {
+              Msg::Warning("Skipping degenerated triangle with area %g", a);
+              nbDegen++;
+            }
+            else
+              faces[i]->triangles.push_back(new MTriangle(v[0], v[1], v[2]));
+          }
+          else
+            faces[i]->triangles.push_back(new MTriangle(v[0], v[1], v[2]));
           unique.insert(mf);
         }
         else {
