@@ -1,4 +1,4 @@
-// Gmsh - Copyright (C) 1997-2024 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2025 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file in the Gmsh root directory for license information.
 // Please report all issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
@@ -47,46 +47,48 @@ int GModel::writeSU2(const std::string &name, bool saveAll,
 
   fprintf(fp, "NDIME= %d\n", ndime);
 
+  std::set<MVertex*, MVertexPtrLessThan> verts;
+  std::set<MElement*, MElementPtrLessThan> elems;
+
   // all interior elements are printed in a single section; indices start at 0;
   // node ordering is the same as VTK
-  int nelem = 0;
+
   if(ndime == 2) {
-    for(auto it = firstFace(); it != lastFace(); it++)
-      if(saveAll || (*it)->physicals.size())
-        nelem += (*it)->getNumMeshElements();
+    for(auto it = firstFace(); it != lastFace(); it++) {
+      if(saveAll || (*it)->physicals.size()) {
+        for(std::size_t i = 0; i < (*it)->getNumMeshElements(); i++) {
+          MElement *e = (*it)->getMeshElement(i);
+          elems.insert(e);
+          for(std::size_t j = 0; j < e->getNumVertices(); j++)
+            verts.insert(e->getVertex(j));
+        }
+      }
+    }
   }
   else {
-    for(auto it = firstRegion(); it != lastRegion(); it++)
-      if(saveAll || (*it)->physicals.size())
-        nelem += (*it)->getNumMeshElements();
+    for(auto it = firstRegion(); it != lastRegion(); it++) {
+      if(saveAll || (*it)->physicals.size()) {
+        for(std::size_t i = 0; i < (*it)->getNumMeshElements(); i++) {
+          MElement *e = (*it)->getMeshElement(i);
+          elems.insert(e);
+          for(std::size_t j = 0; j < e->getNumVertices(); j++)
+            verts.insert(e->getVertex(j));
+        }
+      }
+    }
   }
-  int npoin = indexMeshVertices(saveAll);
 
+  int nelem = elems.size();
+  int npoin = 0;
+  for(auto it : verts) it->setIndex(++npoin);
+
+  // elements and nodes
   Msg::Info("Writing %d elements and %d nodes", nelem, npoin);
-
-  // elements
   fprintf(fp, "NELEM= %d\n", nelem);
   int num = 0;
-  if(ndime == 2) {
-    for(auto it = firstFace(); it != lastFace(); it++)
-      if(saveAll || (*it)->physicals.size())
-        for(std::size_t i = 0; i < (*it)->getNumMeshElements(); i++)
-          (*it)->getMeshElement(i)->writeSU2(fp, num++);
-  }
-  else {
-    for(auto it = firstRegion(); it != lastRegion(); it++)
-      if(saveAll || (*it)->physicals.size())
-        for(std::size_t i = 0; i < (*it)->getNumMeshElements(); i++)
-          (*it)->getMeshElement(i)->writeSU2(fp, num++);
-  }
-
-  // vertices
+  for(auto it : elems) it->writeSU2(fp, num++);
   fprintf(fp, "NPOIN= %d\n", npoin);
-  std::vector<GEntity *> entities;
-  getEntities(entities);
-  for(std::size_t i = 0; i < entities.size(); i++)
-    for(std::size_t j = 0; j < entities[i]->mesh_vertices.size(); j++)
-      entities[i]->mesh_vertices[j]->writeSU2(fp, ndime, scalingFactor);
+  for(auto it : verts) it->writeSU2(fp, ndime, scalingFactor);
 
   // markers for physical groups of dimension (ndime - 1)
   std::map<int, std::vector<GEntity *> > groups[4];
