@@ -1,4 +1,4 @@
-// Gmsh - Copyright (C) 1997-2024 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2025 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file in the Gmsh root directory for license information.
 // Please report all issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
@@ -222,6 +222,13 @@ struct MVertexPtrLessThan {
   }
 };
 
+struct MVertexPtrLessThanIndex {
+  bool operator()(const MVertex *v1, const MVertex *v2) const
+  {
+    return v1->getIndex() < v2->getIndex();
+  }
+};
+
 struct MVertexPtrEqual {
   bool operator()(const MVertex *v1, const MVertex *v2) const
   {
