@@ -1,4 +1,4 @@
-// Gmsh - Copyright (C) 1997-2023 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2025 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file in the Gmsh root directory for license information.
 // Please report all issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
@@ -23,10 +23,10 @@ SVector3 gmshSurface::normal(const SPoint2 &param) const
   return SVector3();
 }
 
-Pair<SVector3, SVector3> gmshSurface::firstDer(const SPoint2 &param)
+std::pair<SVector3, SVector3> gmshSurface::firstDer(const SPoint2 &param)
 {
   Msg::Error("First derivative not implemented for this type of surface");
-  return Pair<SVector3, SVector3>();
+  return std::pair<SVector3, SVector3>();
 }
 
 double gmshSurface::getMetricEigenvalue(const SPoint2 &)
@@ -91,8 +91,9 @@ SPoint3 gmshPolarSphere::point(double u, double v) const
   // at the center of the sphere
   // u=-x/(r+z) v=-y/(r+z)
   double rp2 = u * u + v * v;
-  SPoint3 p(-2 * r * u / (1 + rp2), -2 * r * v / (1 + rp2),
-            r * (1 - rp2) / (1 + rp2));
+  double inv_rp21 = 1.0 / (1 + rp2);
+  SPoint3 p(-2 * r * u * inv_rp21, -2 * r * v * inv_rp21,
+            r * (1 - rp2) * inv_rp21);
   p += o;
   return p;
 }
