@@ -1,4 +1,4 @@
-// Gmsh - Copyright (C) 1997-2024 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2025 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file in the Gmsh root directory for license information.
 // Please report all issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
@@ -18,6 +18,125 @@
 #include "Field.h"
 #include "OS.h"
 
+// for a beta law -- transform h_wall to beta
+//
+
+static double f_beta (double beta, double t, int n){
+  double c = atanh(1/beta);
+  double f = n*(1+atanh((t-1)/beta)/c);
+  return f;
+}
+
+double bissection_get_beta (double beta0, double hw, double length, int n){
+  double t  = hw/length;
+
+  double beta1 = 1. + 1.e-8;
+  double beta2 = 5;
+  double f1 = f_beta(beta1,t,n);
+  double f2 = f_beta(beta2,t,n);
+  if (f1 > 1 && f2 < 1){
+    while(1){
+      double beta3 = (beta1+beta2)*0.5;
+      double f3 = f_beta(beta3,t,n);
+      //      printf("%12.5E %12.5E %12.5E\n",f1,f2,f3);
+      if (fabs(f3- 1) < 1.e-8)return beta3;
+      if (f3 > 1)beta1 = beta3;
+      else beta2 = beta3;
+    }    
+  }
+  return 100;
+}
+
+static double f_bump (double coef, double t, int n){
+  double a;
+  if(coef > 1.0) {
+    a = std::atan2(1.0, std::sqrt(coef - 1.))/std::sqrt(coef - 1.)/n;    
+    double A = (coef-1);
+    double f = (atan(sqrt(A)) - atan(sqrt(A)*(1-2*t)))/2/sqrt(A)/a;
+    return f;
+  }
+  else {
+    a = std::atanh(std::sqrt(1.-coef))/std::sqrt(1-coef)/n;    
+    double A = (1-coef);
+    double f = (atanh(sqrt(A)) - atanh(sqrt(A)*(1-2*t)))/2/sqrt(A)/a;
+    return f;
+  }
+  
+}
+
+// hwall given for the bump
+double bissection_get_a (double r0, double hw, double length, int n){
+  double t  = hw/length;
+
+  double alpha1 = 1.e-8;
+  double alpha2 = 100;
+  double f1 = f_bump(alpha1,t,n);
+  double f2 = f_bump(alpha2,t,n);
+  if (f1 > 1 && f2 < 1){
+    while(1){
+      double alpha3 = (alpha1+alpha2)*0.5;
+      double f3 = f_bump(alpha3,t,n);
+      //      printf("%12.5E %12.5E %12.5E\n",f1,f2,f3);
+      if (fabs(f3- 1) < 1.e-8)return alpha3;
+      if (f3 > 1)alpha1 = alpha3;
+      else alpha2 = alpha3;
+    }    
+  }
+  return 1;
+}
+
+double f_prog(double r, double hw, double length, int n){
+  if (r == 1)return (n*hw/length);
+  double f = hw*(pow(r,n)-1)/(r-1)/length ;
+  return f;
+}
+
+// hwall given for the progression
+double newton_get_r /*bissection_get_r*/ (double r0, double hw, double length, int n){
+  n = n-1;
+
+  double r1 = 1;
+  double r2 = 4;
+  double f1 = f_prog(r1,hw,length,n);
+  double f2 = f_prog(r2,hw,length,n);
+  //  printf("%g %g\n",f1,f2);
+  if (f1 < 1 && f2 > 1){
+    while(1){
+      double r3 = (r1+r2)*0.5;
+      double f3 = f_prog(r3,hw,length,n);
+      //      printf("%22.15E %12.5E %12.5E\n",r1,r2,r3);
+      if (fabs(f3-1) < 1.e-12)return r3;
+      if (f3 < 1)r1 = r3;
+      else r2 = r3;
+    }    
+  }
+  return 1;
+}
+
+
+// for a progression -- transform h_wall to ratio
+double newton_get_2r (double r0, double hw, double length, int n){
+  n = n-1;
+  double r = r0;
+  int it = 0;
+  while(1){
+    double slope = ((n-1) * pow(r,n+1) - n*pow(r,n) + r) / ((r-1)*(r-1)*r);
+    double f = (pow(r,n)-1)/(r-1) - length/hw;
+    //    printf("%g %g\n",f,r);
+    double dr = -f / slope;
+    r = r + dr;
+    if (fabs(f) < 1.e-12){
+      return r;
+    }
+    if (it++ > 100){
+      //      printf("convergence impossible %g\n",f);
+      break;
+    }
+  }
+  return r;
+}
+
+
 typedef struct {
   int Num;
   // t is the local coordinate of the point
@@ -165,9 +284,36 @@ struct F_Transfinite {
     double d = norm(der);
     double coef = ge->meshAttributes.coeffTransfinite;
     int type = ge->meshAttributes.typeTransfinite;
-    int atype = std::abs(type);
     int nbpt = ge->meshAttributes.nbPointsTransfinite;
 
+    //    printf("type = %d coef %g\n",type, coef);
+
+    // transform type = 5 onto type = 1
+    if (type == 5){
+      // for a progression -- transform h_wall to ratio
+      bool sgn = coef > 0;
+      coef = newton_get_r (1.1, fabs(coef), length, nbpt);
+      if (!sgn) coef = 1./coef;
+      type = 1;
+      ge->meshAttributes.typeTransfinite = 1;
+      ge->meshAttributes.coeffTransfinite = coef;
+    }
+    if (type == 6){
+      // for a bump -- transform h_wall to a
+      coef = bissection_get_a (0.1, fabs(coef), length, nbpt);
+      type = 2;
+    }
+    // transform type = 7 onto type = 3
+    if (type == 7){
+      // for a progression -- transform h_wall to ratio
+      bool sgn = coef > 0;
+      coef = bissection_get_beta (2, fabs(coef), length, nbpt);
+      type = 3*(sgn ? 1 : -1);
+    }
+
+    
+    int atype = std::abs(type);
+    
     if(CTX::instance()->mesh.flexibleTransfinite &&
        CTX::instance()->mesh.lcFactor)
       nbpt /= CTX::instance()->mesh.lcFactor;
@@ -699,7 +845,7 @@ int meshGEdgeProcessing(GEdge *ge, const double t_begin, double t_end, int &N,
       CTX::instance()->mesh.flexibleTransfinite) &&
      CTX::instance()->mesh.algoRecombine != 0) {
     std::vector<GFace *> const &faces = ge->faces();
-    if(CTX::instance()->mesh.recombineAll && faces.size()) {
+    if(CTX::instance()->mesh.recombineAll) {
       if(N % 2 == 0) N++;
       if(CTX::instance()->mesh.algoRecombine == 2 ||
          CTX::instance()->mesh.algoRecombine == 4)
