@@ -1,4 +1,4 @@
-// Gmsh - Copyright (C) 1997-2024 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2025 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file in the Gmsh root directory for license information.
 // Please report all issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
@@ -25,8 +25,8 @@ const nodalBasis *BasisFactory::getNodalBasis(int tag)
   // If the Basis has already been built, return it.
   auto it = fs.find(tag);
   if(it != fs.end()) { return it->second; }
-  // Get the parent type to see which kind of basis
-  // we want to create
+
+  // Get the parent type to see which kind of basis we want to create
   nodalBasis *F = nullptr;
   if(tag == MSH_TRI_MINI)
     F = new miniBasisTri();
@@ -50,7 +50,7 @@ const nodalBasis *BasisFactory::getNodalBasis(int tag)
   }
 
   std::pair<std::map<int, nodalBasis *>::const_iterator, bool> inserted;
-#pragma omp critical
+#pragma omp critical(getNodalBasis)
   {
     inserted = fs.insert(std::make_pair(tag, F));
     if(!inserted.second) delete F;
@@ -67,8 +67,14 @@ const JacobianBasis *BasisFactory::getJacobianBasis(int tag, FuncSpaceData fsd)
   if(it != js.end()) return it->second;
 
   JacobianBasis *J = new JacobianBasis(tag, data);
-  js.insert(std::make_pair(data, J));
-  return J;
+
+  std::pair<std::map<FuncSpaceData, JacobianBasis *>::const_iterator, bool> inserted;
+#pragma omp critical(getJacobianBasis)
+  {
+    inserted = js.insert(std::make_pair(data, J));
+    if(!inserted.second) delete J;
+  }
+  return inserted.first->second;
 }
 
 const JacobianBasis *BasisFactory::getJacobianBasis(int tag, int order)
@@ -98,8 +104,14 @@ const CondNumBasis *BasisFactory::getCondNumBasis(int tag, int cnOrder)
   if(it != cs.end()) return it->second;
 
   CondNumBasis *M = new CondNumBasis(tag, cnOrder);
-  cs.insert(std::make_pair(tag, M));
-  return M;
+
+  std::pair<std::map<int, CondNumBasis *>::const_iterator, bool> inserted;
+#pragma omp critical(getCondNumBasis)
+  {
+    inserted = cs.insert(std::make_pair(tag, M));
+    if(!inserted.second) delete M;
+  }
+  return inserted.first->second;
 }
 
 const GradientBasis *BasisFactory::getGradientBasis(int tag, FuncSpaceData fsd)
@@ -110,8 +122,14 @@ const GradientBasis *BasisFactory::getGradientBasis(int tag, FuncSpaceData fsd)
   if(it != gs.end()) return it->second;
 
   GradientBasis *G = new GradientBasis(tag, data);
-  gs.insert(std::make_pair(data, G));
-  return G;
+
+  std::pair<std::map<FuncSpaceData, GradientBasis *>::const_iterator, bool> inserted;
+#pragma omp critical(getGradientBasis)
+  {
+    inserted = gs.insert(std::make_pair(data, G));
+    if(!inserted.second) delete G;
+  }
+  return inserted.first->second;
 }
 
 const GradientBasis *BasisFactory::getGradientBasis(int tag, int order)
@@ -133,8 +151,14 @@ const bezierBasis *BasisFactory::getBezierBasis(FuncSpaceData fsd)
   if(it != bs.end()) return it->second;
 
   bezierBasis *B = new bezierBasis(data);
-  bs.insert(std::make_pair(data, B));
-  return B;
+
+  std::pair<std::map<FuncSpaceData, bezierBasis *>::const_iterator, bool> inserted;
+#pragma omp critical(getBezierBasis)
+  {
+    inserted = bs.insert(std::make_pair(data, B));
+    if(!inserted.second) delete B;
+  }
+  return inserted.first->second;
 }
 
 const bezierBasis *BasisFactory::getBezierBasis(int parentType, int order)
