@@ -1,4 +1,4 @@
-// Gmsh - Copyright (C) 1997-2024 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2025 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file in the Gmsh root directory for license information.
 // Please report all issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
@@ -15,14 +15,14 @@
 int GMSH_CutPlanePlugin::iview = 0;
 
 StringXNumber CutPlaneOptions_Number[] = {
-  {GMSH_FULLRC, "A", GMSH_CutPlanePlugin::callbackA, 1.},
-  {GMSH_FULLRC, "B", GMSH_CutPlanePlugin::callbackB, 0.},
-  {GMSH_FULLRC, "C", GMSH_CutPlanePlugin::callbackC, 0.},
-  {GMSH_FULLRC, "D", GMSH_CutPlanePlugin::callbackD, -0.01},
-  {GMSH_FULLRC, "ExtractVolume", GMSH_CutPlanePlugin::callbackVol, 0},
-  {GMSH_FULLRC, "RecurLevel", GMSH_CutPlanePlugin::callbackRecur, 3},
-  {GMSH_FULLRC, "TargetError", GMSH_CutPlanePlugin::callbackTarget, 1e-4},
-  {GMSH_FULLRC, "View", nullptr, -1.}};
+  {GMSH_FULLRC, "A", GMSH_CutPlanePlugin::callbackA, 1., ""},
+  {GMSH_FULLRC, "B", GMSH_CutPlanePlugin::callbackB, 0., ""},
+  {GMSH_FULLRC, "C", GMSH_CutPlanePlugin::callbackC, 0., ""},
+  {GMSH_FULLRC, "D", GMSH_CutPlanePlugin::callbackD, -0.01, ""},
+  {GMSH_FULLRC, "ExtractVolume", GMSH_CutPlanePlugin::callbackVol, 0, ""},
+  {GMSH_FULLRC, "RecurLevel", GMSH_CutPlanePlugin::callbackRecur, 3, ""},
+  {GMSH_FULLRC, "TargetError", GMSH_CutPlanePlugin::callbackTarget, 1e-4, ""},
+  {GMSH_FULLRC, "View", nullptr, -1., ""}};
 
 extern "C" {
 GMSH_Plugin *GMSH_RegisterCutPlanePlugin() { return new GMSH_CutPlanePlugin(); }
