@@ -1,4 +1,4 @@
-// Gmsh - Copyright (C) 1997-2023 C. Geuzaine, J.-F. Remacle
+// Gmsh - Copyright (C) 1997-2025 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file in the Gmsh root directory for license information.
 // Please report all issues on https://gitlab.onelab.info/gmsh/gmsh/issues.
@@ -806,7 +806,13 @@ bool PViewDataGModel::combineTime(nameData &nd)
 bool PViewDataGModel::skipEntity(int step, int ent)
 {
   if(step >= getNumTimeSteps()) return true;
-  return !_steps[step]->getEntity(ent)->getVisibility();
+
+  // this breaks common usage pattern of loading several model-based views and
+  // expecting all the views to be visible: see #3085
+  // if(!_steps[step]->getModel()->getVisibility()) return true;
+
+  if(!_steps[step]->getEntity(ent)->getVisibility()) return true;
+  return false;
 }
 
 bool PViewDataGModel::skipElement(int step, int ent, int ele,
